version = {'VERS':None,
           'WRAP':None,
           }

well = {'STRT':'START DEPTH',
        'STOP':'STOP DEPTH',
        'STEP':'STEP',
        'NULL':'NULL VALUE',
        'COMP':'COMPANY',
        'WELL':'WELL',
        'FLD':'FIELD',
        'LOC':'LOCATION',
        'PROV':'PROVINCE',
        'CNTY':'COUNTY',
        'STAT':'STATE',
        'CTRY':'COUNTY',
        'SRVC':'SERVICE COMPANY',
        'DATE':'DATE',
        'UWI':'UNIQUE WELL ID',
        'API':'API NUMBER'
        }
